@@ -33,8 +33,10 @@ public class CustomCanvas extends JFrame
 		mxGraph graph = new mxGraph()
 		{
 			public void drawState(mxICanvas canvas, mxCellState state,
-					String label)
+					boolean drawLabel)
 			{
+				String label = (drawLabel) ? state.getLabel() : "";
+
 				// Indirection for wrapped swing canvas inside image canvas (used for creating
 				// the preview image when cells are dragged)
 				if (getModel().isVertex(state.getCell())
@@ -52,7 +54,7 @@ public class CustomCanvas extends JFrame
 				}
 				else
 				{
-					super.drawState(canvas, state, label);
+					super.drawState(canvas, state, drawLabel);
 				}
 			}
 		};
@@ -120,8 +122,8 @@ public class CustomCanvas extends JFrame
 
 			rendererPane.paintComponent(g, vertexRenderer, graphComponent,
 					(int) state.getX() + translate.x, (int) state.getY()
-							+ translate.y, (int) state.getWidth(), (int) state
-							.getHeight(), true);
+							+ translate.y, (int) state.getWidth(),
+					(int) state.getHeight(), true);
 		}
 
 	}
