@@ -1,5 +1,5 @@
 /**
- * $Id: mxCoordinateAssignment.java,v 1.17 2012-06-21 14:20:00 david Exp $
+ * $Id: mxCoordinateAssignment.java,v 1.2 2013/04/26 21:35:56 david Exp $
  * Copyright (c) 2005-2012, JGraph Ltd
  */
 
@@ -1809,24 +1809,10 @@ public class mxCoordinateAssignment implements mxHierarchicalLayoutStage
 				{
 					return 1;
 				}
-				else
-				{
-					if (nudge)
-					{
-						return -1;
-					}
-					else
-					{
-						return 1;
-					}
-				}
 			}
-			else
-			{
-				return 0;
-			}
-		}
 
+			return 0;
+		}
 	}
 
 	/**
