@@ -49,7 +49,7 @@ public class mxMinimumCycleRemover implements mxHierarchicalLayoutStage
 		mxGraphHierarchyModel model = layout.getModel();
 		final Set<mxGraphHierarchyNode> seenNodes = new HashSet<mxGraphHierarchyNode>();
 		final Set<mxGraphHierarchyNode> unseenNodes = new HashSet<mxGraphHierarchyNode>(
-				model.getVertexMapping().values());
+				model.getVertexMapper().values());
 
 		// Perform a dfs through the internal model. If a cycle is found,
 		// reverse it.
@@ -64,7 +64,7 @@ public class mxMinimumCycleRemover implements mxHierarchicalLayoutStage
 			{
 				Object node = modelRoots[i];
 				mxGraphHierarchyNode internalNode = model
-						.getVertexMapping().get(node);
+						.getVertexMapper().get(node);
 				rootsArray[i] = internalNode;
 			}
 		}
