@@ -10,6 +10,6 @@ public interface mxIMarker
 	 * 
 	 */
 	mxPoint paintMarker(mxGraphics2DCanvas canvas, mxCellState state, String type,
-			mxPoint pe, double nx, double ny, double size);
+			mxPoint pe, double nx, double ny, double size, boolean source);
 
 }
