@@ -4,6 +4,7 @@ import java.awt.Rectangle;
 
 import com.mxgraph.canvas.mxGraphics2DCanvas;
 import com.mxgraph.util.mxConstants;
+import com.mxgraph.util.mxRectangle;
 import com.mxgraph.util.mxUtils;
 import com.mxgraph.view.mxCellState;
 
@@ -56,4 +57,29 @@ public class mxSwimlaneShape extends mxBasicShape
 		}
 
 	}
+
+	/**
+	 * 
+	 */
+	protected mxRectangle getGradientBounds(mxGraphics2DCanvas canvas,
+			mxCellState state)
+	{
+		int start = (int) Math.round(mxUtils.getInt(state.getStyle(),
+				mxConstants.STYLE_STARTSIZE, mxConstants.DEFAULT_STARTSIZE)
+				* canvas.getScale());
+		mxRectangle result = new mxRectangle(state);
+
+		if (mxUtils
+				.isTrue(state.getStyle(), mxConstants.STYLE_HORIZONTAL, true))
+		{
+			result.setHeight(Math.min(result.getHeight(), start));
+		}
+		else
+		{
+			result.setWidth(Math.min(result.getWidth(), start));
+		}
+
+		return result;
+	}
+
 }
