@@ -1,5 +1,5 @@
 /**
- * $Id: mxConstants.java,v 1.80 2012-05-24 06:39:54 gaudenz Exp $
+ * $Id: mxConstants.java,v 1.5 2013/02/20 11:41:05 gaudenz Exp $
  * Copyright (c) 2007-2012, JGraph Ltd
  */
 package com.mxgraph.util;
@@ -66,6 +66,7 @@ public class mxConstants
 
 	/**
 	 * Comma separated list of default fonts for CSS properties.
+	 * And the default font family value for new image export.
 	 * Default is Arial, Helvetica.
 	 */
 	public static String DEFAULT_FONTFAMILIES = "Arial,Helvetica";
@@ -86,6 +87,13 @@ public class mxConstants
 	 */
 	public static int DEFAULT_STARTSIZE = 40;
 
+	/**
+	 * Default line height for text output. Default is 1.2. This is ignored for HTML in
+	 * the current version of Java. See
+	 * http://docs.oracle.com/javase/6/docs/api/index.html?javax/swing/text/html/CSS.html
+	 */
+	public static float LINE_HEIGHT = 1.2f;
+
 	/**
 	 * Specifies the line spacing. Default is 0.
 	 */
@@ -1163,6 +1171,12 @@ public class mxConstants
 	 */
 	public static final String EDGESTYLE_ORTHOGONAL = "orthogonalEdgeStyle";
 
+	/**
+	 * Name of the generic segment edge style. Can be used as a string value
+	 * for the STYLE_EDGE style.
+	 */
+	public static final String EDGESTYLE_SEGMENT = "segmentEdgeStyle";
+ 
 	/**
 	 * Name of the ellipse perimeter. Can be used as a string value
 	 * for the STYLE_PERIMETER style.
