@@ -1,5 +1,5 @@
 /**
- * $Id: mxEdgeStyle.java,v 1.47 2011-09-06 19:43:50 gaudenz Exp $
+ * $Id: mxEdgeStyle.java,v 1.4 2013/04/05 12:43:17 gaudenz Exp $
  * Copyright (c) 2007, Gaudenz Alder
  */
 package com.mxgraph.view;
@@ -424,7 +424,10 @@ public class mxEdgeStyle
 				{
 					if (pt != null)
 					{
-						result.add(new mxPoint(x, pt.getY()));
+						if (!target.contains(x, pt.getY()) && !source.contains(x, pt.getY()))
+						{
+							result.add(new mxPoint(x, pt.getY()));
+						}
 					}
 					else
 					{
@@ -517,7 +520,10 @@ public class mxEdgeStyle
 				{
 					if (pt != null)
 					{
-						result.add(new mxPoint(pt.getX(), y));
+						if (!target.contains(pt.getX(), y) && !source.contains(pt.getX(), y))
+						{
+							result.add(new mxPoint(pt.getX(), y));
+						}
 					}
 					else
 					{
@@ -532,6 +538,177 @@ public class mxEdgeStyle
 		}
 	};
 
+	/**
+	 * Implements an orthogonal edge style. Use <mxEdgeSegmentHandler>
+	 * as an interactive handler for this style.
+	 */
+	public static mxEdgeStyleFunction SegmentConnector = new mxEdgeStyleFunction()
+	{
+
+		/* (non-Javadoc)
+		 * @see com.mxgraph.view.mxEdgeStyle.mxEdgeStyleFunction#apply(com.mxgraph.view.mxCellState, com.mxgraph.view.mxCellState, com.mxgraph.view.mxCellState, java.util.List, java.util.List)
+		 */
+		public void apply(mxCellState state, mxCellState source, mxCellState target, List<mxPoint> hints, List<mxPoint> result)
+		{
+			// Creates array of all way- and terminalpoints
+			List<mxPoint> pts = state.absolutePoints;
+			boolean horizontal = true;
+			mxPoint hint = null;
+
+			// Adds the first point
+			mxPoint pt = pts.get(0);
+
+			if (pt == null && source != null)
+			{
+				pt = new mxPoint(state.view.getRoutingCenterX(source), state.view.getRoutingCenterY(source));
+			}
+			else if (pt != null)
+			{
+				pt = (mxPoint) pt.clone();
+			}
+
+			int lastInx = pts.size() - 1;
+
+			// Adds the waypoints
+			if (hints != null && hints.size() > 0)
+			{
+				hint = state.view.transformControlPoint(state, hints.get(0));
+
+				mxCellState currentTerm = source;
+				mxPoint currentPt = pts.get(0);
+				boolean hozChan = false;
+				boolean vertChan = false;
+				mxPoint currentHint = hint;
+				int hintsLen = hints.size();
+
+				for (int i = 0; i < 2; i++)
+				{
+					boolean fixedVertAlign = currentPt != null && currentPt.getX() == currentHint.getX();
+					boolean fixedHozAlign = currentPt != null && currentPt.getY() == currentHint.getY();
+					boolean inHozChan = currentTerm != null
+							&& (currentHint.getY() >= currentTerm.getY() && currentHint.getY() <= currentTerm.getY()
+									+ currentTerm.getHeight());
+					boolean inVertChan = currentTerm != null
+							&& (currentHint.getX() >= currentTerm.getX() && currentHint.getX() <= currentTerm.getX()
+									+ currentTerm.getWidth());
+
+					hozChan = fixedHozAlign || (currentPt == null && inHozChan);
+					vertChan = fixedVertAlign || (currentPt == null && inVertChan);
+
+					if (currentPt != null && (!fixedHozAlign && !fixedVertAlign) && (inHozChan || inVertChan))
+					{
+						horizontal = inHozChan ? false : true;
+						break;
+					}
+
+					if (vertChan || hozChan)
+					{
+						horizontal = hozChan;
+
+						if (i == 1)
+						{
+							// Work back from target end
+							horizontal = hints.size() % 2 == 0 ? hozChan : vertChan;
+						}
+
+						break;
+					}
+
+					currentTerm = target;
+					currentPt = pts.get(lastInx);
+					currentHint = state.view.transformControlPoint(state, hints.get(hintsLen - 1));
+				}
+
+				if (horizontal
+						&& ((pts.get(0) != null && pts.get(0).getY() != hint.getY()) || (pts.get(0) == null && source != null && (hint
+								.getY() < source.getY() || hint.getY() > source.getY() + source.getHeight()))))
+				{
+					result.add(new mxPoint(pt.getX(), hint.getY()));
+				}
+				else if (!horizontal
+						&& ((pts.get(0) != null && pts.get(0).getX() != hint.getX()) || (pts.get(0) == null && source != null && (hint
+								.getX() < source.getX() || hint.getX() > source.getX() + source.getWidth()))))
+				{
+					result.add(new mxPoint(hint.getX(), pt.getY()));
+				}
+
+				if (horizontal)
+				{
+					pt.setY(hint.getY());
+				}
+				else
+				{
+					pt.setX(hint.getX());
+				}
+
+				for (int i = 0; i < hints.size(); i++)
+				{
+					horizontal = !horizontal;
+					hint = state.view.transformControlPoint(state, hints.get(i));
+
+					//				mxLog.show();
+					//				mxLog.debug('hint', i, hint.x, hint.y);
+
+					if (horizontal)
+					{
+						pt.setY(hint.getY());
+					}
+					else
+					{
+						pt.setX(hint.getX());
+					}
+
+					result.add((mxPoint) pt.clone());
+				}
+			}
+			else
+			{
+				hint = pt;
+				// FIXME: First click in connect preview toggles orientation
+				horizontal = true;
+			}
+
+			// Adds the last point
+			pt = pts.get(lastInx);
+
+			if (pt == null && target != null)
+			{
+				pt = new mxPoint(state.view.getRoutingCenterX(target), state.view.getRoutingCenterY(target));
+			}
+
+			if (horizontal
+					&& ((pts.get(lastInx) != null && pts.get(lastInx).getY() != hint.getY()) || (pts.get(lastInx) == null && target != null && (hint
+							.getY() < target.getY() || hint.getY() > target.getY() + target.getHeight()))))
+			{
+				result.add(new mxPoint(pt.getX(), hint.getY()));
+			}
+			else if (!horizontal
+					&& ((pts.get(lastInx) != null && pts.get(lastInx).getX() != hint.getX()) || (pts.get(lastInx) == null && target != null && (hint
+							.getX() < target.getX() || hint.getX() > target.getX() + target.getWidth()))))
+			{
+				result.add(new mxPoint(hint.getX(), pt.getY()));
+			}
+
+			// Removes bends inside the source terminal for floating ports
+			if (pts.get(0) == null && source != null)
+			{
+				while (result.size() > 1 && source.contains(result.get(1).getX(), result.get(1).getY()))
+				{
+					result.remove(1);
+				}
+			}
+
+			// Removes bends inside the target terminal
+			if (pts.get(lastInx) == null && target != null)
+			{
+				while (result.size() > 1 && target.contains(result.get(result.size() - 1).getX(), result.get(result.size() - 1).getY()))
+				{
+					result.remove(result.size() - 1);
+				}
+			}
+		}
+	};
+	
 	public static double orthBuffer = 10;
 
 	public static double[][] dirVectors = new double[][] { { -1, 0 },
@@ -605,7 +782,7 @@ public class mxEdgeStyle
 	 * An orthogonal connector that avoids connecting vertices and 
 	 * respects port constraints
 	 */
-	public static mxEdgeStyleFunction orthConnector = new mxEdgeStyleFunction()
+	public static mxEdgeStyleFunction OrthConnector = new mxEdgeStyleFunction()
 	{
 
 		/* (non-Javadoc)
@@ -614,6 +791,16 @@ public class mxEdgeStyle
 		public void apply(mxCellState state, mxCellState source,
 				mxCellState target, List<mxPoint> points, List<mxPoint> result)
 		{
+			mxGraph graph = state.view.graph;
+			boolean sourceEdge = source == null ? false : graph.getModel().isEdge(source.cell);
+			boolean targetEdge = target == null ? false : graph.getModel().isEdge(target.cell);
+
+			if ((points != null && points.size() > 0) || (sourceEdge) || (targetEdge))
+			{
+				mxEdgeStyle.SegmentConnector.apply(state, source, target, points, result);
+				return;
+			}
+
 			if (source != null && target != null)
 			{
 				double scaledOrthBuffer = orthBuffer
